@@ -40,7 +40,7 @@ from skimage.util import random_noise
 from scipy.ndimage import distance_transform_edt
 from skimage.morphology import skeletonize
 from stardist.models.base import StarDistBase
-
+import math
 
 
 class StarDistBaseLite(StarDist3D):
@@ -48,7 +48,7 @@ class StarDistBaseLite(StarDist3D):
         super().__init__(config=config, name=name, basedir=basedir)
 
 
-def predict_prob(self, img, axes=None, normalizer=None, n_tiles=None, show_tile_progress=True, **predict_kwargs):
+     def predict_prob(self, img, axes=None, normalizer=None, n_tiles=None, show_tile_progress=True, **predict_kwargs):
        
 
         x, axes, axes_net, axes_net_div_by, _permute_axes, resizer, n_tiles, grid, grid_dict, channel, predict_direct, tiling_setup = \
@@ -58,12 +58,11 @@ def predict_prob(self, img, axes=None, normalizer=None, n_tiles=None, show_tile_
             tile_generator, output_shape, create_empty_output = tiling_setup()
 
             prob = create_empty_output(1)
-           
             if self._is_multiclass():
                 prob_class = create_empty_output(self.config.n_classes+1)
-                result = (prob, prob_class)
+                result = (prob, prob, prob_class)
             else:
-                result = (prob)
+                result = (prob, prob)
 
             for tile, s_src, s_dst in tile_generator:
                 # predict_direct -> prob, dist, [prob_class if multi_class]
@@ -77,21 +76,26 @@ def predict_prob(self, img, axes=None, normalizer=None, n_tiles=None, show_tile_
                 s_src, s_dst = tuple(s_src), tuple(s_dst)
                 # print(s_src,s_dst)
                 for part, part_tile in zip(result, result_tile):
-                    part[s_dst] = part_tile[s_src]
+                    try:
+                       part[s_dst] = part_tile[s_src]
+                    except:
+                        pass
+                
         else:
             # predict_direct -> prob, dist, [prob_class if multi_class]
             result = predict_direct(x)
 
         result = [resizer.after(part, axes_net) for part in result]
 
-     
+        # result = (prob, dist) for legacy or (prob, dist, prob_class) for multiclass
 
         # prob
         result[0] = np.take(result[0],0,axis=channel)
-
+        # dist
+        result[1] = result[0]
         if self._is_multiclass():
             # prob_class
-            result[1] = np.moveaxis(result[1],channel,-1)
+            result[2] = np.moveaxis(result[2],channel,-1)
 
         return tuple(result)
 
@@ -340,11 +344,11 @@ def NotumQueen(save_dir, fname, denoising_model, projection_model, mask_model, s
     
     
 
-def CreateTrackMate_CSV( LabelName,   savedir):
+def CreateTrackMate_CSV( Label,Name,savedir):
 
 
-    Label = imread(LabelName)
-    Name = os.path.basename(os.path.splitext(LabelName)[0])
+    
+    
 
 
     TimeList = []
@@ -765,7 +769,7 @@ n_tiles = (1,2,2), UseProbability = True, filtersize = 0, globalthreshold = 1.0E
     imwrite((ProbabilityResults + Name+ '.tif' ) , ProbabilityMap.astype('float32'))
     imwrite((MarkerResults + Name+ '.tif' ) , Markers.astype('uint16'))
         
-    CreateTrackMate_CSV( SizedSmartSeeds,   SaveDir)
+    CreateTrackMate_CSV( SizedSmartSeeds,Name, SaveDir)
     
     return SizedSmartSeeds, SizedMask    
 
@@ -954,10 +958,7 @@ def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection =
     print('Predicting Instances')
     MidImage, details = model.predict_instances(image, n_tiles = n_tiles)
     print('Predicting Probabilities')
-    if UseProbability:
-      SmallProbability = model.predict_prob(image, n_tiles = n_tiles)
-    else:
-      SmallProbability, SmallDistance  = model.predict(image, n_tiles = n_tiles)
+    SmallProbability, SmallDistance  = model.predict(image, n_tiles = n_tiles)
 
 
     print('Predictions Done')
